### 安装
    pip install xiaobaiinstaller
    or
    pip install -U xiaobaiinstaller

### 使用
    打开cmd输入以下命令，回车运行
    xiaobaiinstaller

### 备注
    - 目前支持：JMeter与JDK的安装
    - 可以手动获取JMeter或者JDK的版本，推荐选择新版本
    - 软件默认安装在D:\Program Files盘下，后续添加可自定义安装在其它目录下
    - 后续再增加其它软件安装